from setuptools import setup

setup(
    name='timeanalysismoon',
    version='0.8',
    packages=['timeanalysismoon'],
    author='CoderMungan',
    author_email='codermungan@gmail.com',
    description='A time analysis decorator for Python functions',
    long_description='A decorator that measures and prints the execution time of a function.',
    url='https://github.com/CoderMungan/timeanalysismoon',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
    entry_points={
        'console_scripts': [
            'timeanalysismoon=timeanalysismoon.cli:main',
        ],
    },
)